@@ -32,12 +32,13 @@
 # POSSIBILITY OF SUCH DAMAGE.
 
 import re
+
 from .vcs import Git
 
 
 class RepositorySpecification(object):
     # Match groups are server and path on server.
-    VCS_REGEX = re.compile('(?:https?:\/\/|ssh:\/\/|git:\/\/|git@)([\w.-]+)[:/]([\w/-]*)(?:\.git)?$')
+    VCS_REGEX = re.compile('(?:https?:\/\/|ssh:\/\/|git:\/\/|git@)((?:[a-fA-F0-9]{40}@)?[\w.-]+)[:/]([\w/-]*)(?:\.git)?$')
 
     def __init__(self, name, data):
         self.name = name
